import stamp.core.*;
import stamp.util.text.*;
import stamp.peripheral.web.*;

/**
  PinkV2 test program
  Author: Peter Verkaik (peterverkaik@boselectro.nl)
  Date: 09 december 2007
*/

public class PinkV2_test {

  //Javelin pin assignments
  static final int pinRX = CPU.pin10;
  static final int pinTX = CPU.pin11;

  //Pink declarations
  static ScaledTimer16 pinkTimer = new ScaledTimer16(1000,100); //timeout is 1000 units, unit is 100*10uSec
  static Uart tx = new Uart(Uart.dirTransmit, pinTX, Uart.dontInvert, Uart.speed9600, Uart.stop1);
  static Uart rx = new Uart(Uart.dirReceive, pinRX, Uart.dontInvert, Uart.speed9600, Uart.stop1);
  static PinkV2 myPink = new PinkV2('0',tx,rx,pinkTimer);

  //buffer
  static char[] buf = new char[64]; //buffer size equals maximum Pink variable size, holds asciiz string

  static void main() {
    Format.printf("PinkV2 test program\n");

    //send email message
    do {
      myPink.getStatus();
    } while (!myPink.isReady());
    //set TO address
    myPink.writeVar(myPink.Nb_varET,"someone@somewhere.com");
    //set FROM address
    myPink.writeVar(myPink.Nb_varEF,"PINK@netburner.com");
    //set SUBJECT
    myPink.writeVar(myPink.Nb_varES,"Test Message From PINK");
    //set MESSAGE CONTENT
    myPink.writeVar(myPink.Nb_varEC,"Message Content Goes Here!");
    //set SMTP server
    myPink.writeVar(myPink.Nb_varEV,"smtp.server.com");
    //set smtp USERNAME (optional on some servers)
//    myPink.writeVar(myPink.Nb_varEU,"username");
    //set smtp PASSWORD (optional on some servers)
//    myPink.writeVar(myPink.Nb_varEP,"password");
    //set smtp AUTHENTICATION on/off (optional on some servers)
//    myPink.writeVar(myPink.Nb_varEA,"1");
    //send email
    myPink.sendEmail();
    //check email busy
    do {
      myPink.getStatus();
    } while (!myPink.isReady());
    //check email status
    if (myPink.isSent()) Format.printf("Email sent succesfully\n");
    else Format.printf("Email send failure\n");

    //send udp message
    //set DESTINATION ip address
    myPink.writeVar(myPink.Nb_varBI,"192.168.1.7");
    //set MESSAGE CONTENT
    myPink.writeVar(myPink.Nb_varBM,"Please Send Me A Reply To Port 10000!");
    //set udp port
    myPink.writeVar(myPink.Nb_varBP,"10000");
    //send udp
    myPink.sendUdp();
    Format.printf("UDP message sent\n");
    
    //receive udp message
    //check udp receive status
    do {
      myPink.getStatus();
    } while (!myPink.isUdp());
    //read SOURCE ip address
    myPink.readVar(myPink.Nb_varSU,buf); 
    Format.printf("UDP message received from %s\n",buf);
    //read received udp message
    myPink.readVar(myPink.Nb_varBM,buf); 
    Format.printf("Message: %s\n",buf);

    Format.printf("\nProgram finished\n");
    while (true) {
    }
  }

}